use bevy::prelude::*;
use std::time::Duration; // Needed for Timer in Player

// --- Components ---
#[derive(Component)]
pub struct Player {
    pub speed: f32,
    pub shoot_cooldown: Timer,
}

#[derive(Component)]
pub struct Bullet;

#[derive(Component, Clone, Copy, PartialEq, Eq, Debug)] // Added derive for common traits
pub enum EnemyType {
    Grunt,
    Boss, // Added Boss type
}

#[derive(Component)]
pub struct Enemy {
    pub enemy_type: EnemyType, // Add type field
    pub shoot_cooldown: Timer,
}

#[derive(Component)]
pub struct Invincible {
    pub timer: Timer,
}

#[derive(Component)]
pub struct FormationTarget {
    pub position: Vec3,
}

#[derive(Component, Clone, PartialEq)]
pub enum EnemyState {
    Entering,    // Flying onto the screen towards formation target
    InFormation, // Holding position in the formation
    Attacking,   // Diving towards the player
}

#[derive(Component)]
pub struct EnemyBullet;

// Game Over UI Component (might move to ui.rs later if more UI exists)
#[derive(Component)]
pub struct GameOverUI;