use bevy::prelude::*;
use std::time::Duration; // Needed for Timer

// --- Resources ---
#[derive(Resource)]
pub struct EnemySpawnTimer {
    pub timer: Timer,
}

#[derive(Resource)]
pub struct PlayerLives {
    pub count: u32,
}

#[derive(Resource)]
pub struct PlayerRespawnTimer {
    pub timer: Timer,
}

// New struct to define formation positions
#[derive(Clone, Debug)]
pub struct FormationLayout {
    pub name: String, // Optional name for debugging/identification
    pub positions: Vec<Vec3>,
}

// Default implementation for easy initialization
impl Default for FormationLayout {
    fn default() -> Self {
        // Default to the original grid formation for now
        let mut positions = Vec::with_capacity(crate::constants::FORMATION_ENEMY_COUNT);
        for i in 0..crate::constants::FORMATION_ENEMY_COUNT {
            let row = i / crate::constants::FORMATION_COLS;
            let col = i % crate::constants::FORMATION_COLS;
            let target_x = (col as f32 - (crate::constants::FORMATION_COLS as f32 - 1.0) / 2.0) * crate::constants::FORMATION_X_SPACING;
            let target_y = crate::constants::FORMATION_BASE_Y - (row as f32 * crate::constants::FORMATION_Y_SPACING);
            positions.push(Vec3::new(target_x, target_y, 0.0));
        }
        FormationLayout {
            name: "Default Grid".to_string(),
            positions,
        }
    }
}
#[derive(Resource)]
pub struct Score {
    pub value: u32,
}

#[derive(Resource)]
pub struct CurrentStage {
    pub number: u32,
    pub waiting_for_clear: bool, // Flag to check if we should check for stage clear
}

#[derive(Resource)]
pub struct FormationState {
    pub next_slot_index: usize,
    pub total_spawned_this_stage: usize,
    pub formation_complete: bool, // Flag to indicate if all enemies are in position
}

#[derive(Resource)]
pub struct AttackDiveTimer {
    pub timer: Timer,
}